"""
This example script shows how to blink multiple LEDs at different
rates simultaneously without each affecting the others.
Reference: https://learn.adafruit.com/multi-tasking-with-circuitpython/multiple-leds
"""

import time
import board
import digitalio

BLINK_LIST = [
    { "ON": 0.40, "OFF": 0.25, "PREV_TIME": -1, "PIN": board.B0 },
    { "ON": 0.25, "OFF": 0.25, "PREV_TIME": -1, "PIN": board.B1 },
    { "ON": 0.35, "OFF": 0.25, "PREV_TIME": -1, "PIN": board.B2 },
    { "ON": 0.50, "OFF": 0.25, "PREV_TIME": -1, "PIN": board.B10}    
]

for led in BLINK_LIST:
    led["PIN"] = digitalio.DigitalInOut(led["PIN"])
    led["PIN"].direction = digitalio.Direction.OUTPUT

while True:
    now = time.monotonic()

    for led in BLINK_LIST:
        if led["PIN"].value is False:
            if now >= led["PREV_TIME"] + led["OFF"]:
                led["PREV_TIME"] = now
                led["PIN"].value = True
        if led["PIN"].value is True:
            if now >= led["PREV_TIME"] + led["ON"]:
                led["PREV_TIME"] = now
                led["PIN"].value = False
